import { Component, Input, OnInit, EventEmitter, Output } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import { Capability } from "../../../../model/capability";
import { CapabilityLauncherService } from "../../../../services/capability-launcher.service";
import { WorkflowLauncherService } from "../../../../services/workflow-launcher.service";
import { CapabilityExecution } from "../../../../model/capability-execution";
import {CapabilityRequestService} from "../../../../services/capability-request.service";

@Component({
  selector: "app-request-operations",
  templateUrl: "./request-operations.component.html",
  styleUrls: ["./request-operations.component.scss"],
})
export class RequestOperationsComponent implements OnInit {

  constructor(
    public capabilityLauncherService: CapabilityLauncherService,
    public workflowLauncherService: WorkflowLauncherService,
    private capabilityRequestService: CapabilityRequestService,
  ) {}
  @Input() capabilityRequest: CapabilityRequest;
  @Input() capability: Capability;
  public capabilityExecution: CapabilityExecution;
  @Output() cartaLaunched: EventEmitter<any> = new EventEmitter<any>();
  public cartaResponse: any;
  public hasBeenClicked: boolean = false;
  public userEmail: string;

  // Observer for submitting capability request objects (returns a capability execution)
  public submitRequestObserver = {
    next: (submitResponse: CapabilityExecution) => {
      this.capabilityExecution = submitResponse;
      window.location.reload();
    },
    error: (error) => {
      console.log(error);
    },
  };

  public launchCartaObserver = {
    next: (resp: any) => {
      this.cartaResponse = resp;
      this.hasBeenClicked = true;
      this.cartaLaunched.emit({ type: "carta", email: this.userEmail });
    },
    error: (error) => {
      console.log(error);

      this.cartaLaunched.emit({ type: "error"});
    },
  }

  public followonRequestObserver = {
    next: (followonResponse: CapabilityRequest) => {
      if (followonResponse.id) {
        // Capability request created; ID found
        // Redirect to request status page
        this.capabilityRequestService.redirectToRequestStatusPage(followonResponse.id);
      }
    },
    error: (error) => {
      console.log(error);
    },
  };

  launchCarta($event) {
    let params = {
      need_data: false,
      notify_ready: true,
      product_locator: null,
      user_email: this.userEmail,
      parent_wf_request_id: this.capabilityRequest.current_execution.current_workflow_request_id,
    };
    this.workflowLauncherService
      .createAndSubmitWorkflow("carta", params)
      .subscribe(this.launchCartaObserver);
  }

  ngOnInit(): void {
    this.userEmail = this.capabilityRequest.parameters.user_email.toString();
  }
}
